import 'dart:io';

import 'package:agschat_example/constants.dart';
import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/helper/KeyboardAvoider.dart';
import 'package:agschat_example/helper/colors.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/helper/images.dart';
import 'package:agschat_example/view/chats_list_view.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class CreateGroup extends StatefulWidget {
  CreateGroup({Key? key, this.selectedUserObj, this.selectedUserIds})
      : super(key: key);
  var selectedUserObj;
  var selectedUserIds;
  @override
  _CreateGroupState createState() => _CreateGroupState();
}

class _CreateGroupState extends State<CreateGroup> {
  TextEditingController groupNameController = TextEditingController();
  var imageBytes;
  var groupImage = File("").obs;
  var selectedUserObj = [];
  var selectedUserIds = [];
  @override
  void initState() {
    super.initState();
    selectedUserObj = [];
    selectedUserIds = [];
    // if (Get.arguments != null) {
    selectedUserObj = widget.selectedUserObj;
    selectedUserIds = widget.selectedUserIds;
    selectedUserObj.add({
      "groups": myGroups.value,
      "mobile_email": myMobileEmail.value,
      "name": myUserName.value,
      "userId": myUserId,
      "profilePicture": myProfilePicture.value
    });
    selectedUserIds.add(myUserId);
    // }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          "Create Group",
          style:
              CustomTextStyles.medium(fontSize: 16.0, fontColor: Colors.black),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      body: Column(
        children: [
          InkWell(
            borderRadius: BorderRadius.circular(200),
            onTap: () async {
              var pickedFile;
              FilePickerResult? result = await FilePicker.platform.pickFiles(
                type: FileType.media,
                withData: true,
              );
              imageBytes = result!.files[0].bytes;
              pickedFile = File(result.paths[0].toString());
              groupImage.value = pickedFile;
            },
            child: Stack(
              alignment: Alignment.center,
              children: [
                Obx(
                  () => !groupImage.value.isAbsolute
                      ? Container(
                          height: 200,
                          width: 200,
                          decoration: const BoxDecoration(
                            shape: BoxShape.circle,
                            image: DecorationImage(
                              image: ExactAssetImage(
                                  ImageResource.groupPlaceHolder),
                              fit: BoxFit.cover,
                            ),
                          ),
                        )
                      : ClipRRect(
                          borderRadius: BorderRadius.circular(200),
                          child: Container(
                            color: Colors.black12,
                            child: Image.file(
                              File(
                                groupImage.value.path,
                              ),
                              height: 200.0,
                              width: 200.0,
                            ),
                          ),
                        ),
                ),
                const Icon(Icons.camera_alt_outlined, color: Colors.white),
              ],
            ),
          ),
          const SizedBox(height: 10),
          Expanded(
            child: KeyboardAvoider(
              autoScroll: true,
              child: Column(
                children: [
                  Padding(
                    padding: const EdgeInsets.only(
                        left: 20, right: 20, top: 8, bottom: 8),
                    child: TextField(
                      controller: groupNameController,
                      onChanged: (val) {},
                      decoration: InputDecoration(
                        hintText: "Enter group name",
                        hintStyle: CustomTextStyles.medium(
                            fontSize: 14.0, fontColor: Color(0xffBFBFC4)),
                        filled: true,
                        fillColor: const Color(0xffEEEEEF),
                        border: commonBorderStyle,
                        enabledBorder: commonBorderStyle,
                        disabledBorder: commonBorderStyle,
                        focusedBorder: commonBorderStyle,
                        focusedErrorBorder: commonBorderStyle,
                        errorBorder: commonBorderStyle,
                        contentPadding:
                            const EdgeInsets.only(left: 6, right: 6),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          )
        ],
      ),
      bottomNavigationBar: SafeArea(
        child: GestureDetector(
          onTap: () {
            var param = {
              'secretKey': secKey,
              'isGroup': true,
              'createdBy': myUserId,
              'groupId': '',
              'groupImage': imageBytes,
              'members': selectedUserIds,
              'isDeactivateUser': false,
              'modifiedBy': "",
              'name': groupNameController.text,
              "online": [],
              "pinnedGroup": [],
              "readCount": [
                {"unreadCount": "0", "userId": ""}
              ],
              "typing": [],
              "blockUsers": [],
              "viewBy": selectedUserIds,
              "recentMessage": {},
              'users': selectedUserObj,
            };
            if (groupNameController.text.isEmpty) {
              Common.getSnackToast(
                  title: "Error", message: "Please enter group name");
            } else {
              chat(param, success: () {
                // Get.offAll(() => const ChatsListView());
                Navigator.pushReplacement(
                    context,
                    MaterialPageRoute(
                        builder: (BuildContext context) => ChatsListView()));
              }, context: context);
            }
          },
          child: Container(
            height: 50,
            margin:
                const EdgeInsets.only(top: 16, left: 20, right: 20, bottom: 10),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(8.0),
              color: const Color(0xff0D659D),
            ),
            child: Center(
              child: Text(
                "Create Group",
                style: CustomTextStyles.medium(
                    fontSize: 18.0, fontColor: Colors.white),
              ),
            ),
          ),
        ),
      ),
    );
  }

  // Common border for textField
  var commonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(color: Color(0xffE6E6E6), width: 1.0),
  );
}
